@@ -1,7 +1,7 @@
 /*
  * This file is part of the API Extractor project.
  *
- * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+ * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
  * Copyright 2005 Roberto Raggi <roberto@kdevelop.org>
  *
  * Contact: PySide team <contact@pyside.org>
@@ -368,7 +368,7 @@ _InputIterator pp::handle_include(bool __skip_current_path, _InputIterator __fir
         name.reserve(255);
         expand_include(__first, __last, std::back_inserter(name));
         std::string::iterator it = skip_blanks(name.begin(), name.end());
-        if (it != name.end() && (*it != '<' || *it != '"')) {
+        if (it != name.end() && !(*it == '<' || *it == '"')) {
             std::cerr << "** WARNING APIExtractor does not support the use "
                          "of #include directives without passing either "
                          "\"<path/to/header.h>\" or \"./path/to/header.h\", "
@@ -623,6 +623,8 @@ _InputIterator pp::handle_define(_InputIterator __first, _InputIterator __last)
             } else {
                 __first = skip_comment_or_divop(__first, __last);
                 env.current_line += skip_comment_or_divop.lines;
+                if (__first == __last)
+                    break;
             }
         }
 
