@@ -24,6 +24,9 @@
 
 namespace Photon
 {
+const ClassType Base::staticType;
+template <> const ClassType TemplateBase<IdentityType>::staticType;
+template <> const ClassType TemplateBase<DuplicatorType>::staticType;
 int callCalculateForValueDuplicatorPointer(ValueDuplicator* value)
 {
     return value->calculate();
