@@ -1,7 +1,7 @@
 /*
  * This file is part of the Shiboken Python Binding Generator project.
  *
- * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+ * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
  *
  * Contact: PySide team <contact@pyside.org>
  *
@@ -107,10 +107,20 @@ public:
             inline int someMethod(SomeInnerClass*) { return 0; }
             virtual OkThisIsRecursiveEnough* someVirtualMethod(OkThisIsRecursiveEnough* arg) { return arg; }
         };
+    protected:
+        enum ProtectedEnum {
+            ProtectedItem0,
+            ProtectedItem1
+        };
     };
     struct SomeOtherInnerClass {
         std::list<SomeInnerClass> someInnerClasses;
     };
+protected:
+    enum ProtectedEnum {
+        ProtectedItem0,
+        ProtectedItem1
+    };
 };
 
 class DerivedFromNamespace : public SomeClass::SomeInnerClass::OkThisIsRecursiveEnough
